"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _GT14Status:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _GT14StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GT14Status.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LT14: _GT14Status.ValueType  # 0
    """"""

    GE14: _GT14Status.ValueType  # 1
    """"""

    UNKNOWN_GT14: _GT14Status.ValueType  # 2
    """"""

class GT14Status(_GT14Status, metaclass=_GT14StatusEnumTypeWrapper):
    """"""
    pass

LT14: GT14Status.ValueType  # 0
""""""

GE14: GT14Status.ValueType  # 1
""""""

UNKNOWN_GT14: GT14Status.ValueType  # 2
""""""

global___GT14Status = GT14Status


class _NFTStatus:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _NFTStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NFTStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED: _NFTStatus.ValueType  # 0
    """"""

    NORMAL: _NFTStatus.ValueType  # 1
    """"""

    DOING: _NFTStatus.ValueType  # 2
    """"""

class NFTStatus(_NFTStatus, metaclass=_NFTStatusEnumTypeWrapper):
    """"""
    pass

UNDEFINED: NFTStatus.ValueType  # 0
""""""

NORMAL: NFTStatus.ValueType  # 1
""""""

DOING: NFTStatus.ValueType  # 2
""""""

global___NFTStatus = NFTStatus


class _PolicyAgreeStatus:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PolicyAgreeStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PolicyAgreeStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNSIGNED: _PolicyAgreeStatus.ValueType  # 0
    """"""

    ACCEPTED: _PolicyAgreeStatus.ValueType  # 1
    """"""

    EXPIRED: _PolicyAgreeStatus.ValueType  # 2
    """"""

class PolicyAgreeStatus(_PolicyAgreeStatus, metaclass=_PolicyAgreeStatusEnumTypeWrapper):
    """"""
    pass

UNSIGNED: PolicyAgreeStatus.ValueType  # 0
""""""

ACCEPTED: PolicyAgreeStatus.ValueType  # 1
""""""

EXPIRED: PolicyAgreeStatus.ValueType  # 2
""""""

global___PolicyAgreeStatus = PolicyAgreeStatus


class _PolicyType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PolicyTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PolicyType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_POLICY: _PolicyType.ValueType  # 0
    """"""

    WALLET: _PolicyType.ValueType  # 1
    """"""

    SALE: _PolicyType.ValueType  # 2
    """"""

class PolicyType(_PolicyType, metaclass=_PolicyTypeEnumTypeWrapper):
    """"""
    pass

UNKNOWN_POLICY: PolicyType.ValueType  # 0
""""""

WALLET: PolicyType.ValueType  # 1
""""""

SALE: PolicyType.ValueType  # 2
""""""

global___PolicyType = PolicyType


class AgreePolicyReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___AgreePolicyReply = AgreePolicyReply

class AgreePolicyReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    policy_type: global___PolicyType.ValueType
    """"""

    version: typing.Text
    """"""

    def __init__(self,
        *,
        policy_type: global___PolicyType.ValueType = ...,
        version: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_type",b"policy_type","version",b"version"]) -> None: ...
global___AgreePolicyReq = AgreePolicyReq

class BasicInfoReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CUSTOMER_SERVICE_URL_FIELD_NUMBER: builtins.int
    AGREEMENT_URL_FIELD_NUMBER: builtins.int
    PRIVACY_URL_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    customer_service_url: typing.Text
    """"""

    agreement_url: typing.Text
    """"""

    privacy_url: typing.Text
    """"""

    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Link]:
        """"""
        pass
    def __init__(self,
        *,
        customer_service_url: typing.Text = ...,
        agreement_url: typing.Text = ...,
        privacy_url: typing.Text = ...,
        links: typing.Optional[typing.Iterable[global___Link]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["agreement_url",b"agreement_url","customer_service_url",b"customer_service_url","links",b"links","privacy_url",b"privacy_url"]) -> None: ...
global___BasicInfoReply = BasicInfoReply

class BasicInfoReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid",b"mid"]) -> None: ...
global___BasicInfoReq = BasicInfoReq

class Display(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BG_THEME_LIGHT_FIELD_NUMBER: builtins.int
    BG_THEME_NIGHT_FIELD_NUMBER: builtins.int
    NFT_POSTER_FIELD_NUMBER: builtins.int
    NFT_RAW_FIELD_NUMBER: builtins.int
    bg_theme_light: typing.Text
    """"""

    bg_theme_night: typing.Text
    """"""

    nft_poster: typing.Text
    """"""

    nft_raw: typing.Text
    """"""

    def __init__(self,
        *,
        bg_theme_light: typing.Text = ...,
        bg_theme_night: typing.Text = ...,
        nft_poster: typing.Text = ...,
        nft_raw: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_theme_light",b"bg_theme_light","bg_theme_night",b"bg_theme_night","nft_poster",b"nft_poster","nft_raw",b"nft_raw"]) -> None: ...
global___Display = Display

class GetLastPolicyReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHORT_DESC_FIELD_NUMBER: builtins.int
    DETAIL_JUMP_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    short_desc: typing.Text
    """"""

    detail_jump: typing.Text
    """"""

    version: typing.Text
    """"""

    def __init__(self,
        *,
        short_desc: typing.Text = ...,
        detail_jump: typing.Text = ...,
        version: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["detail_jump",b"detail_jump","short_desc",b"short_desc","version",b"version"]) -> None: ...
global___GetLastPolicyReply = GetLastPolicyReply

class GetLastPolicyReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    policy_type: global___PolicyType.ValueType
    """"""

    def __init__(self,
        *,
        policy_type: global___PolicyType.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_type",b"policy_type"]) -> None: ...
global___GetLastPolicyReq = GetLastPolicyReq

class GetUserInfoReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    AVATAR_URL_FIELD_NUMBER: builtins.int
    HELP_URL_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    name: typing.Text
    """"""

    address: typing.Text
    """"""

    avatar_url: typing.Text
    """"""

    help_url: typing.Text
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        address: typing.Text = ...,
        avatar_url: typing.Text = ...,
        help_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","avatar_url",b"avatar_url","help_url",b"help_url","mid",b"mid","name",b"name"]) -> None: ...
global___GetUserInfoReply = GetUserInfoReply

class GetUserInfoReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid",b"mid"]) -> None: ...
global___GetUserInfoReq = GetUserInfoReq

class Link(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    LINK_URL_FIELD_NUMBER: builtins.int
    TRACK_EVENT_ID_FIELD_NUMBER: builtins.int
    name: typing.Text
    """"""

    link_url: typing.Text
    """"""

    track_event_id: typing.Text
    """"""

    def __init__(self,
        *,
        name: typing.Text = ...,
        link_url: typing.Text = ...,
        track_event_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["link_url",b"link_url","name",b"name","track_event_id",b"track_event_id"]) -> None: ...
global___Link = Link

class ListNFTByMidReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NFTS_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def nfts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NFT]:
        """"""
        pass
    anchor_id: builtins.int
    """"""

    end: builtins.bool
    """"""

    def __init__(self,
        *,
        nfts: typing.Optional[typing.Iterable[global___NFT]] = ...,
        anchor_id: builtins.int = ...,
        end: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id",b"anchor_id","end",b"end","nfts",b"nfts"]) -> None: ...
global___ListNFTByMidReply = ListNFTByMidReply

class ListNFTByMidReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    category: typing.Text
    """"""

    biz_type: typing.Text
    """"""

    anchor_id: builtins.int
    """"""

    page_size: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        category: typing.Text = ...,
        biz_type: typing.Text = ...,
        anchor_id: builtins.int = ...,
        page_size: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id",b"anchor_id","biz_type",b"biz_type","category",b"category","mid",b"mid","page_size",b"page_size"]) -> None: ...
global___ListNFTByMidReq = ListNFTByMidReq

class ListOrderByMidReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ORDERS_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def orders(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Order]:
        """"""
        pass
    anchor_id: builtins.int
    """"""

    end: builtins.bool
    """"""

    def __init__(self,
        *,
        orders: typing.Optional[typing.Iterable[global___Order]] = ...,
        anchor_id: builtins.int = ...,
        end: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id",b"anchor_id","end",b"end","orders",b"orders"]) -> None: ...
global___ListOrderByMidReply = ListOrderByMidReply

class ListOrderByMidReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    ANCHOR_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    anchor_id: builtins.int
    """"""

    page_size: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        anchor_id: builtins.int = ...,
        page_size: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["anchor_id",b"anchor_id","mid",b"mid","page_size",b"page_size"]) -> None: ...
global___ListOrderByMidReq = ListOrderByMidReq

class NFT(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NFT_ID_FIELD_NUMBER: builtins.int
    ITEM_NAME_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    DISPLAY_FIELD_NUMBER: builtins.int
    DETAIL_URL_FIELD_NUMBER: builtins.int
    NFT_STATUS_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    nft_id: typing.Text
    """"""

    item_name: typing.Text
    """"""

    serial_number: typing.Text
    """"""

    issuer: typing.Text
    """"""

    @property
    def display(self) -> global___Display:
        """"""
        pass
    detail_url: typing.Text
    """"""

    nft_status: global___NFTStatus.ValueType
    """"""

    item_id: builtins.int
    """"""

    def __init__(self,
        *,
        nft_id: typing.Text = ...,
        item_name: typing.Text = ...,
        serial_number: typing.Text = ...,
        issuer: typing.Text = ...,
        display: typing.Optional[global___Display] = ...,
        detail_url: typing.Text = ...,
        nft_status: global___NFTStatus.ValueType = ...,
        item_id: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["display",b"display"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["detail_url",b"detail_url","display",b"display","issuer",b"issuer","item_id",b"item_id","item_name",b"item_name","nft_id",b"nft_id","nft_status",b"nft_status","serial_number",b"serial_number"]) -> None: ...
global___NFT = NFT

class Order(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEM_NAME_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    TX_HASH_FIELD_NUMBER: builtins.int
    TX_TIME_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    ISSUE_TIME_FIELD_NUMBER: builtins.int
    TOKEN_ID_FIELD_NUMBER: builtins.int
    DISPLAY_FIELD_NUMBER: builtins.int
    CONTRACT_ADDRESS_FIELD_NUMBER: builtins.int
    HASH_JUMP_FIELD_NUMBER: builtins.int
    CONTRACT_JUMP_FIELD_NUMBER: builtins.int
    DISABLE_BROWSER_JUMP_FIELD_NUMBER: builtins.int
    item_name: typing.Text
    """"""

    serial_number: typing.Text
    """"""

    tx_hash: typing.Text
    """"""

    tx_time: typing.Text
    """"""

    issuer: typing.Text
    """"""

    issue_time: typing.Text
    """"""

    token_id: typing.Text
    """"""

    @property
    def display(self) -> global___Display:
        """"""
        pass
    contract_address: typing.Text
    """"""

    hash_jump: typing.Text
    """"""

    contract_jump: typing.Text
    """"""

    disable_browser_jump: builtins.bool
    """"""

    def __init__(self,
        *,
        item_name: typing.Text = ...,
        serial_number: typing.Text = ...,
        tx_hash: typing.Text = ...,
        tx_time: typing.Text = ...,
        issuer: typing.Text = ...,
        issue_time: typing.Text = ...,
        token_id: typing.Text = ...,
        display: typing.Optional[global___Display] = ...,
        contract_address: typing.Text = ...,
        hash_jump: typing.Text = ...,
        contract_jump: typing.Text = ...,
        disable_browser_jump: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["display",b"display"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["contract_address",b"contract_address","contract_jump",b"contract_jump","disable_browser_jump",b"disable_browser_jump","display",b"display","hash_jump",b"hash_jump","issue_time",b"issue_time","issuer",b"issuer","item_name",b"item_name","serial_number",b"serial_number","token_id",b"token_id","tx_hash",b"tx_hash","tx_time",b"tx_time"]) -> None: ...
global___Order = Order

class UserCheckReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POLICY_STATUS_FIELD_NUMBER: builtins.int
    GT14_FIELD_NUMBER: builtins.int
    policy_status: builtins.int
    """"""

    gt14: builtins.int
    """"""

    def __init__(self,
        *,
        policy_status: builtins.int = ...,
        gt14: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gt14",b"gt14","policy_status",b"policy_status"]) -> None: ...
global___UserCheckReply = UserCheckReply

class UserCheckReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    POLICY_TYPE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    policy_type: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        policy_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid",b"mid","policy_type",b"policy_type"]) -> None: ...
global___UserCheckReq = UserCheckReq



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from bilireq.grpc.protos.bilibili.app.view.v1 import view_pb2 as bilibili_dot_app_dot_view_dot_v1_dot_view__pb2


class ViewStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.View = channel.unary_unary(
                '/bilibili.app.view.v1.View/View',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReply.FromString,
                )
        self.ViewProgress = channel.unary_unary(
                '/bilibili.app.view.v1.View/ViewProgress',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReply.FromString,
                )
        self.ShortFormVideoDownload = channel.unary_unary(
                '/bilibili.app.view.v1.View/ShortFormVideoDownload',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReply.FromString,
                )
        self.ClickPlayerCard = channel.unary_unary(
                '/bilibili.app.view.v1.View/ClickPlayerCard',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickPlayerCardReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
                )
        self.ClickActivitySeason = channel.unary_unary(
                '/bilibili.app.view.v1.View/ClickActivitySeason',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickActivitySeasonReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
                )
        self.Season = channel.unary_unary(
                '/bilibili.app.view.v1.View/Season',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReply.FromString,
                )
        self.ExposePlayerCard = channel.unary_unary(
                '/bilibili.app.view.v1.View/ExposePlayerCard',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ExposePlayerCardReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
                )
        self.AddContract = channel.unary_unary(
                '/bilibili.app.view.v1.View/AddContract',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.AddContractReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
                )
        self.FeedView = channel.unary_unary(
                '/bilibili.app.view.v1.View/FeedView',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReply.FromString,
                )
        self.ChronosPkg = channel.unary_unary(
                '/bilibili.app.view.v1.View/ChronosPkg',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ChronosPkgReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.Chronos.FromString,
                )
        self.CacheView = channel.unary_unary(
                '/bilibili.app.view.v1.View/CacheView',
                request_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReq.SerializeToString,
                response_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReply.FromString,
                )


class ViewServicer(object):
    """Missing associated documentation comment in .proto file."""

    def View(self, request, context):
        """视频页详情页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ViewProgress(self, request, context):
        """视频播放过程中的数据
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShortFormVideoDownload(self, request, context):
        """短视频下载
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClickPlayerCard(self, request, context):
        """点击播放器卡片事件
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClickActivitySeason(self, request, context):
        """点击大型活动页预约
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Season(self, request, context):
        """合集详情页
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExposePlayerCard(self, request, context):
        """播放器卡片曝光
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddContract(self, request, context):
        """点击签订契约
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeedView(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChronosPkg(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CacheView(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ViewServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'View': grpc.unary_unary_rpc_method_handler(
                    servicer.View,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReply.SerializeToString,
            ),
            'ViewProgress': grpc.unary_unary_rpc_method_handler(
                    servicer.ViewProgress,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReply.SerializeToString,
            ),
            'ShortFormVideoDownload': grpc.unary_unary_rpc_method_handler(
                    servicer.ShortFormVideoDownload,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReply.SerializeToString,
            ),
            'ClickPlayerCard': grpc.unary_unary_rpc_method_handler(
                    servicer.ClickPlayerCard,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickPlayerCardReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.SerializeToString,
            ),
            'ClickActivitySeason': grpc.unary_unary_rpc_method_handler(
                    servicer.ClickActivitySeason,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickActivitySeasonReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.SerializeToString,
            ),
            'Season': grpc.unary_unary_rpc_method_handler(
                    servicer.Season,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReply.SerializeToString,
            ),
            'ExposePlayerCard': grpc.unary_unary_rpc_method_handler(
                    servicer.ExposePlayerCard,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ExposePlayerCardReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.SerializeToString,
            ),
            'AddContract': grpc.unary_unary_rpc_method_handler(
                    servicer.AddContract,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.AddContractReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.SerializeToString,
            ),
            'FeedView': grpc.unary_unary_rpc_method_handler(
                    servicer.FeedView,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReply.SerializeToString,
            ),
            'ChronosPkg': grpc.unary_unary_rpc_method_handler(
                    servicer.ChronosPkg,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ChronosPkgReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.Chronos.SerializeToString,
            ),
            'CacheView': grpc.unary_unary_rpc_method_handler(
                    servicer.CacheView,
                    request_deserializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReq.FromString,
                    response_serializer=bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'bilibili.app.view.v1.View', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class View(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def View(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/View',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ViewProgress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ViewProgress',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ViewProgressReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShortFormVideoDownload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ShortFormVideoDownload',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ShortFormVideoDownloadReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClickPlayerCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ClickPlayerCard',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickPlayerCardReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClickActivitySeason(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ClickActivitySeason',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ClickActivitySeasonReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Season(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/Season',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.SeasonReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExposePlayerCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ExposePlayerCard',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ExposePlayerCardReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/AddContract',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.AddContractReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.NoReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FeedView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/FeedView',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.FeedViewReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChronosPkg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/ChronosPkg',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.ChronosPkgReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.Chronos.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CacheView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/bilibili.app.view.v1.View/CacheView',
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReq.SerializeToString,
            bilibili_dot_app_dot_view_dot_v1_dot_view__pb2.CacheViewReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ErrorRequest(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ERROR_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    DELAY_FIELD_NUMBER: builtins.int
    error: builtins.int
    """"""

    time: builtins.int
    """"""

    delay: builtins.int
    """"""

    def __init__(self,
        *,
        error: builtins.int = ...,
        time: builtins.int = ...,
        delay: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delay",b"delay","error",b"error","time",b"time"]) -> None: ...
global___ErrorRequest = ErrorRequest

class ErrorResponse(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HOST_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    host: typing.Text
    """"""

    time: builtins.int
    """"""

    def __init__(self,
        *,
        host: typing.Text = ...,
        time: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host",b"host","time",b"time"]) -> None: ...
global___ErrorResponse = ErrorResponse

class PingRequest(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TIME_FIELD_NUMBER: builtins.int
    time: builtins.int
    """"""

    def __init__(self,
        *,
        time: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["time",b"time"]) -> None: ...
global___PingRequest = PingRequest

class PingResponse(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HOST_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    host: typing.Text
    """"""

    time: builtins.int
    """"""

    def __init__(self,
        *,
        host: typing.Text = ...,
        time: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host",b"host","time",b"time"]) -> None: ...
global___PingResponse = PingResponse

class SayRequest(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENT_FIELD_NUMBER: builtins.int
    content: typing.Text
    """"""

    def __init__(self,
        *,
        content: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content"]) -> None: ...
global___SayRequest = SayRequest

class SayResponse(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HOST_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    host: typing.Text
    """"""

    content: typing.Text
    """"""

    time: builtins.int
    """"""

    def __init__(self,
        *,
        host: typing.Text = ...,
        content: typing.Text = ...,
        time: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","host",b"host","time",b"time"]) -> None: ...
global___SayResponse = SayResponse



from typing import Union

from bilireq.utils import get, post
from bilireq.utils.av_bv import bv2av


async def get_video_base_info(video_id: Union[int, str]):
    """获取哔哩哔哩视频基本信息"""
    base_url = "https://api.bilibili.com/x/web-interface/view"
    if isinstance(video_id, int):
        url = f"{base_url}?aid={video_id}"
    elif video_id[:2].lower() == "av" and video_id[2:].isdigit():
        url = f"{base_url}?aid={video_id[2:]}"
    elif video_id[:2].lower() == "bv":
        url = f"{base_url}?bvid={video_id}"
    else:
        raise ValueError(f"{video_id} 不是一个有效的 AV 或 BV 号")
    return await get(url)


async def get_video_share(video_id: Union[int, str]):
    """模拟移动端哔哩哔哩视频分享点击"""
    if isinstance(video_id, int):
        av_id = video_id
    elif video_id[:2].lower() == "av" and video_id[2:].isdigit():
        av_id = int(video_id[2:])
    elif video_id[:2].lower() == "bv":
        av_id = bv2av(video_id)
    else:
        raise ValueError(f"{video_id} 不是一个有效的 AV 或 BV 号")

    body = {
        "build": "6060600",
        "buvid": "0",
        "oid": av_id,
        "platform": "android",
        "share_channel": "QQ",
        "share_id": "main.ugc-video-detail.0.0.pv",
        "share_mode": "7",
    }
    headers = {"Content-Type": "application/x-www-form-urlencoded"}
    url = "https://api.biliapi.net/x/share/click"
    return await post(url, data=body, headers=headers)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/ad/v1/ad.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x62ilibili/ad/v1/ad.proto\x12\x0e\x62ilibili.ad.v1\x1a\x1egoogle/protobuf/wrappers.proto\"Y\n\rAdsControlDto\x12\x11\n\thas_danmu\x18\x01 \x01(\x05\x12\x0c\n\x04\x63ids\x18\x02 \x03(\x03\x12\'\n\x03\x65ps\x18\x03 \x03(\x0b\x32\x1a.bilibili.ad.v1.AdOgvEpDto\"1\n\nAdOgvEpDto\x12\x0c\n\x04\x65pid\x18\x01 \x01(\x03\x12\x15\n\rhas_recommend\x18\x02 \x01(\x08\"\x91\x02\n\x10SourceContentDto\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x05\x12\x13\n\x0bresource_id\x18\x03 \x01(\x05\x12\x11\n\tis_ad_loc\x18\x04 \x01(\x08\x12\x30\n\x0bserver_type\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x11\n\tclient_ip\x18\x06 \x01(\t\x12/\n\ncard_index\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\r\n\x05index\x18\x08 \x01(\x05\x12)\n\nad_content\x18\t \x01(\x0b\x32\x15.bilibili.ad.v1.AdDto\"\x8b\x02\n\x05\x41\x64\x44to\x12\x13\n\x0b\x63reative_id\x18\x01 \x01(\x03\x12\r\n\x05\x61\x64_cb\x18\x02 \x01(\t\x12\x30\n\x05\x65xtra\x18\x03 \x01(\x0b\x32!.bilibili.ad.v1.AdContentExtraDto\x12\x0f\n\x07\x63m_mark\x18\x04 \x01(\x05\x12\x13\n\x0btop_view_id\x18\x05 \x01(\x03\x12\x15\n\rcreative_type\x18\x06 \x01(\x05\x12\x11\n\tcard_type\x18\x07 \x01(\x05\x12\x16\n\x0e\x63reative_style\x18\x08 \x01(\x05\x12\r\n\x05is_ad\x18\t \x01(\x05\x12\x35\n\x10\x63reative_content\x18\n \x01(\x0b\x32\x1b.bilibili.ad.v1.CreativeDto\"\xd2\x06\n\x11\x41\x64\x43ontentExtraDto\x12\x0e\n\x06layout\x18\x01 \x01(\t\x12\x11\n\tshow_urls\x18\x02 \x03(\t\x12\x12\n\nclick_urls\x18\x03 \x03(\t\x12\x1c\n\x14\x64\x61nmu_list_show_urls\x18\x04 \x03(\t\x12\x1d\n\x15\x64\x61nmu_list_click_urls\x18\x05 \x03(\t\x12\x1e\n\x16\x64\x61nmu_detail_show_urls\x18\x06 \x03(\t\x12\x1e\n\x16\x64\x61nmu_trolley_add_urls\x18\x07 \x03(\t\x12\x15\n\ruse_ad_web_v2\x18\x08 \x01(\x08\x12\x16\n\x0eopen_whitelist\x18\t \x03(\t\x12\x39\n\x12\x64ownload_whitelist\x18\n \x01(\x0b\x32\x1d.bilibili.ad.v1.AppPackageDto\x12\'\n\x04\x63\x61rd\x18\x0b \x01(\x0b\x32\x19.bilibili.ad.v1.AdCardDto\x12\x13\n\x0breport_time\x18\x0c \x01(\x05\x12\x19\n\x11\x61ppstore_priority\x18\r \x01(\x05\x12\x12\n\nsales_type\x18\x0e \x01(\x05\x12\x1b\n\x13preload_landingpage\x18\x0f \x01(\x05\x12\x18\n\x10special_industry\x18\x10 \x01(\x08\x12\x1d\n\x15special_industry_tips\x18\x11 \x01(\t\x12\x1e\n\x16\x65nable_download_dialog\x18\x12 \x01(\x08\x12\x14\n\x0c\x65nable_share\x18\x13 \x01(\x08\x12\x1c\n\x14upzone_entrance_type\x18\x14 \x01(\x05\x12!\n\x19upzone_entrance_report_id\x18\x15 \x01(\x05\x12\x32\n\nshare_info\x18\x16 \x01(\x0b\x32\x1e.bilibili.ad.v1.AdShareInfoDto\x12\x17\n\x0ftopview_pic_url\x18\x17 \x01(\t\x12\x19\n\x11topview_video_url\x18\x18 \x01(\t\x12\x12\n\nclick_area\x18\x19 \x01(\x05\x12\x0f\n\x07shop_id\x18\x1a \x01(\x03\x12\x0e\n\x06up_mid\x18\x1b \x01(\x03\x12\x10\n\x08track_id\x18\x1c \x01(\t\x12\"\n\x1a\x65nable_store_direct_launch\x18\x1d \x01(\x05\x12\x12\n\nproduct_id\x18\x1e \x01(\x03\"\x83\x02\n\x0b\x43reativeDto\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\x12\x11\n\timage_md5\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x11\n\tclick_url\x18\x06 \x01(\t\x12\x10\n\x08show_url\x18\x07 \x01(\t\x12\x10\n\x08video_id\x18\x08 \x01(\x03\x12\x15\n\rthumbnail_url\x18\t \x01(\t\x12\x19\n\x11thumbnail_url_md5\x18\n \x01(\t\x12\x10\n\x08logo_url\x18\x0b \x01(\t\x12\x10\n\x08logo_md5\x18\x0c \x01(\t\x12\x10\n\x08username\x18\r \x01(\t\"\x87\x02\n\rAppPackageDto\x12\x0c\n\x04size\x18\x01 \x01(\x03\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x10\n\x08\x61pk_name\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x10\n\x08\x62ili_url\x18\x05 \x01(\t\x12\x0b\n\x03md5\x18\x06 \x01(\t\x12\x0c\n\x04icon\x18\x07 \x01(\t\x12\x10\n\x08\x64\x65v_name\x18\x08 \x01(\t\x12\x10\n\x08\x61uth_url\x18\t \x01(\t\x12\x11\n\tauth_name\x18\n \x01(\t\x12\x0f\n\x07version\x18\x0b \x01(\t\x12\x13\n\x0bupdate_time\x18\x0c \x01(\t\x12\x14\n\x0cprivacy_name\x18\r \x01(\t\x12\x13\n\x0bprivacy_url\x18\x0e \x01(\t\"\x90\t\n\tAdCardDto\x12\x11\n\tcard_type\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x12\n\nextra_desc\x18\x04 \x01(\t\x12\x11\n\tlong_desc\x18\x05 \x01(\t\x12\x13\n\x0bshort_title\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x61nmu_title\x18\x07 \x01(\t\x12\x14\n\x0c\x64\x61nmu_height\x18\x08 \x01(\x05\x12\x13\n\x0b\x64\x61nmu_width\x18\t \x01(\x05\x12\x12\n\ndanmu_life\x18\n \x01(\x05\x12\x13\n\x0b\x64\x61nmu_begin\x18\x0b \x01(\x05\x12\x13\n\x0b\x64\x61nmu_color\x18\x0c \x01(\t\x12\x13\n\x0b\x64\x61nmu_h5url\x18\r \x01(\t\x12\x12\n\ndanmu_icon\x18\x0e \x01(\t\x12\x11\n\tfold_time\x18\x0f \x01(\x05\x12\x0e\n\x06\x61\x64_tag\x18\x10 \x01(\t\x12*\n\x06\x63overs\x18\x11 \x03(\x0b\x32\x1a.bilibili.ad.v1.AdCoverDto\x12\x10\n\x08jump_url\x18\x12 \x01(\t\x12%\n\x1dimax_landing_page_json_string\x18\x13 \x01(\t\x12\x12\n\ncallup_url\x18\x14 \x01(\t\x12\x15\n\runiversal_app\x18\x15 \x01(\t\x12\x11\n\tori_price\x18\x16 \x01(\t\x12\x11\n\tcur_price\x18\x17 \x01(\x05\x12\x12\n\nprice_desc\x18\x18 \x01(\t\x12\x14\n\x0cprice_symbol\x18\x19 \x01(\t\x12\x17\n\x0fgoods_cur_price\x18\x1a \x01(\t\x12\x17\n\x0fgoods_ori_price\x18\x1b \x01(\t\x12\'\n\x04good\x18\x1c \x01(\x0b\x32\x19.bilibili.ad.v1.AdGoodDto\x12\x0c\n\x04rank\x18\x1d \x01(\x05\x12\x11\n\thot_score\x18\x1e \x01(\x05\x12+\n\x06\x62utton\x18\x1f \x01(\x0b\x32\x1b.bilibili.ad.v1.AdButtonDto\x12\x12\n\nadver_logo\x18  \x01(\t\x12\x12\n\nadver_name\x18! \x01(\t\x12\x16\n\x0e\x61\x64ver_page_url\x18\" \x01(\t\x12\x15\n\rvideo_barrage\x18# \x03(\t\x12\x37\n\x0c\x61\x64_tag_style\x18$ \x01(\x0b\x32!.bilibili.ad.v1.AdBusinessMarkDto\x12\x31\n\x05video\x18% \x01(\x0b\x32\".bilibili.ad.v1.AdAutoPlayVideoDto\x12:\n\x0e\x66\x65\x65\x64\x62\x61\x63k_panel\x18& \x01(\x0b\x32\".bilibili.ad.v1.AdFeedbackPanelDto\x12\x11\n\tadver_mid\x18\' \x01(\x03\x12\x18\n\x10\x61\x64ver_account_id\x18( \x01(\x03\x12\x10\n\x08\x64uration\x18) \x01(\t\x12\x32\n\rquality_infos\x18* \x03(\x0b\x32\x1b.bilibili.ad.v1.QualityInfo\x12\x14\n\x0c\x64ynamic_text\x18+ \x01(\t\x12\'\n\x05\x61\x64ver\x18, \x01(\x0b\x32\x18.bilibili.ad.v1.AdverDto\x12\x13\n\x0bgrade_level\x18- \x01(\x05\"D\n\x0e\x41\x64ShareInfoDto\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x11\n\timage_url\x18\x03 \x01(\t\"y\n\nAdCoverDto\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04loop\x18\x02 \x01(\x05\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x13\n\x0breport_urls\x18\x04 \x03(\t\x12\x14\n\x0cimage_height\x18\x05 \x01(\x05\x12\x13\n\x0bimage_width\x18\x06 \x01(\x05\"\x97\x01\n\x0b\x41\x64\x42uttonDto\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x13\n\x0breport_urls\x18\x04 \x01(\t\x12\x18\n\x10\x64lsuc_callup_url\x18\x05 \x01(\t\x12\x0f\n\x07game_id\x18\x06 \x01(\x05\x12\x1a\n\x12game_monitor_param\x18\x07 \x01(\t\"\x8a\x02\n\x11\x41\x64\x42usinessMarkDto\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x12\n\ntext_color\x18\x03 \x01(\t\x12\x18\n\x10text_color_night\x18\x04 \x01(\t\x12\x10\n\x08\x62g_color\x18\x05 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x06 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x07 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x08 \x01(\t\x12\x0f\n\x07img_url\x18\t \x01(\t\x12\x12\n\nimg_height\x18\n \x01(\x05\x12\x11\n\timg_width\x18\x0b \x01(\x05\x12\x17\n\x0f\x62g_border_color\x18\x0c \x01(\t\"\x8f\x02\n\x12\x41\x64\x41utoPlayVideoDto\x12\x0c\n\x04\x61vid\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0c\n\x04page\x18\x03 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\x12\x11\n\tauto_play\x18\x07 \x01(\x08\x12\x15\n\rbtn_dyc_color\x18\x08 \x01(\x08\x12\x14\n\x0c\x62tn_dyc_time\x18\t \x01(\x05\x12\x0e\n\x06\x62iz_id\x18\n \x01(\x03\x12\x15\n\rprocess0_urls\x18\x0b \x03(\t\x12\x14\n\x0cplay_3s_urls\x18\x0c \x03(\t\x12\x14\n\x0cplay_5s_urls\x18\r \x03(\t\x12\x13\n\x0borientation\x18\x0e \x01(\x05\"v\n\x12\x41\x64\x46\x65\x65\x64\x62\x61\x63kPanelDto\x12\x17\n\x0fpanel_type_text\x18\x01 \x01(\t\x12G\n\x15\x66\x65\x65\x64\x62\x61\x63k_panel_detail\x18\x02 \x03(\x0b\x32(.bilibili.ad.v1.AdFeedbackPanelModuleDto\"\xb5\x01\n\x18\x41\x64\x46\x65\x65\x64\x62\x61\x63kPanelModuleDto\x12\x11\n\tmodule_id\x18\x01 \x01(\x05\x12\x10\n\x08icon_url\x18\x02 \x01(\t\x12\x11\n\tjump_type\x18\x03 \x01(\x05\x12\x10\n\x08jump_url\x18\x04 \x01(\t\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x41\n\x0fsecondary_panel\x18\x06 \x03(\x0b\x32(.bilibili.ad.v1.AdSecondFeedbackPanelDto\";\n\x18\x41\x64SecondFeedbackPanelDto\x12\x11\n\treason_id\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\"N\n\tAdGoodDto\x12\x0f\n\x07item_id\x18\x01 \x01(\x03\x12\x0e\n\x06sku_id\x18\x02 \x01(\x03\x12\x0f\n\x07shop_id\x18\x03 \x01(\x03\x12\x0f\n\x07sku_num\x18\x04 \x01(\x03\"b\n\x0bQualityInfo\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\r\n\x05is_bg\x18\x03 \x01(\x08\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\"\x84\x01\n\x08\x41\x64verDto\x12\x10\n\x08\x61\x64ver_id\x18\x01 \x01(\x03\x12\x12\n\nadver_logo\x18\x02 \x01(\t\x12\x12\n\nadver_name\x18\x03 \x01(\t\x12\x12\n\nadver_type\x18\x04 \x01(\x05\x12\x16\n\x0e\x61\x64ver_page_url\x18\x05 \x01(\t\x12\x12\n\nadver_desc\x18\x06 \x01(\tb\x06proto3')



_ADSCONTROLDTO = DESCRIPTOR.message_types_by_name['AdsControlDto']
_ADOGVEPDTO = DESCRIPTOR.message_types_by_name['AdOgvEpDto']
_SOURCECONTENTDTO = DESCRIPTOR.message_types_by_name['SourceContentDto']
_ADDTO = DESCRIPTOR.message_types_by_name['AdDto']
_ADCONTENTEXTRADTO = DESCRIPTOR.message_types_by_name['AdContentExtraDto']
_CREATIVEDTO = DESCRIPTOR.message_types_by_name['CreativeDto']
_APPPACKAGEDTO = DESCRIPTOR.message_types_by_name['AppPackageDto']
_ADCARDDTO = DESCRIPTOR.message_types_by_name['AdCardDto']
_ADSHAREINFODTO = DESCRIPTOR.message_types_by_name['AdShareInfoDto']
_ADCOVERDTO = DESCRIPTOR.message_types_by_name['AdCoverDto']
_ADBUTTONDTO = DESCRIPTOR.message_types_by_name['AdButtonDto']
_ADBUSINESSMARKDTO = DESCRIPTOR.message_types_by_name['AdBusinessMarkDto']
_ADAUTOPLAYVIDEODTO = DESCRIPTOR.message_types_by_name['AdAutoPlayVideoDto']
_ADFEEDBACKPANELDTO = DESCRIPTOR.message_types_by_name['AdFeedbackPanelDto']
_ADFEEDBACKPANELMODULEDTO = DESCRIPTOR.message_types_by_name['AdFeedbackPanelModuleDto']
_ADSECONDFEEDBACKPANELDTO = DESCRIPTOR.message_types_by_name['AdSecondFeedbackPanelDto']
_ADGOODDTO = DESCRIPTOR.message_types_by_name['AdGoodDto']
_QUALITYINFO = DESCRIPTOR.message_types_by_name['QualityInfo']
_ADVERDTO = DESCRIPTOR.message_types_by_name['AdverDto']
AdsControlDto = _reflection.GeneratedProtocolMessageType('AdsControlDto', (_message.Message,), {
  'DESCRIPTOR' : _ADSCONTROLDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdsControlDto)
  })
_sym_db.RegisterMessage(AdsControlDto)

AdOgvEpDto = _reflection.GeneratedProtocolMessageType('AdOgvEpDto', (_message.Message,), {
  'DESCRIPTOR' : _ADOGVEPDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdOgvEpDto)
  })
_sym_db.RegisterMessage(AdOgvEpDto)

SourceContentDto = _reflection.GeneratedProtocolMessageType('SourceContentDto', (_message.Message,), {
  'DESCRIPTOR' : _SOURCECONTENTDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.SourceContentDto)
  })
_sym_db.RegisterMessage(SourceContentDto)

AdDto = _reflection.GeneratedProtocolMessageType('AdDto', (_message.Message,), {
  'DESCRIPTOR' : _ADDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdDto)
  })
_sym_db.RegisterMessage(AdDto)

AdContentExtraDto = _reflection.GeneratedProtocolMessageType('AdContentExtraDto', (_message.Message,), {
  'DESCRIPTOR' : _ADCONTENTEXTRADTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdContentExtraDto)
  })
_sym_db.RegisterMessage(AdContentExtraDto)

CreativeDto = _reflection.GeneratedProtocolMessageType('CreativeDto', (_message.Message,), {
  'DESCRIPTOR' : _CREATIVEDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.CreativeDto)
  })
_sym_db.RegisterMessage(CreativeDto)

AppPackageDto = _reflection.GeneratedProtocolMessageType('AppPackageDto', (_message.Message,), {
  'DESCRIPTOR' : _APPPACKAGEDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AppPackageDto)
  })
_sym_db.RegisterMessage(AppPackageDto)

AdCardDto = _reflection.GeneratedProtocolMessageType('AdCardDto', (_message.Message,), {
  'DESCRIPTOR' : _ADCARDDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdCardDto)
  })
_sym_db.RegisterMessage(AdCardDto)

AdShareInfoDto = _reflection.GeneratedProtocolMessageType('AdShareInfoDto', (_message.Message,), {
  'DESCRIPTOR' : _ADSHAREINFODTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdShareInfoDto)
  })
_sym_db.RegisterMessage(AdShareInfoDto)

AdCoverDto = _reflection.GeneratedProtocolMessageType('AdCoverDto', (_message.Message,), {
  'DESCRIPTOR' : _ADCOVERDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdCoverDto)
  })
_sym_db.RegisterMessage(AdCoverDto)

AdButtonDto = _reflection.GeneratedProtocolMessageType('AdButtonDto', (_message.Message,), {
  'DESCRIPTOR' : _ADBUTTONDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdButtonDto)
  })
_sym_db.RegisterMessage(AdButtonDto)

AdBusinessMarkDto = _reflection.GeneratedProtocolMessageType('AdBusinessMarkDto', (_message.Message,), {
  'DESCRIPTOR' : _ADBUSINESSMARKDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdBusinessMarkDto)
  })
_sym_db.RegisterMessage(AdBusinessMarkDto)

AdAutoPlayVideoDto = _reflection.GeneratedProtocolMessageType('AdAutoPlayVideoDto', (_message.Message,), {
  'DESCRIPTOR' : _ADAUTOPLAYVIDEODTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdAutoPlayVideoDto)
  })
_sym_db.RegisterMessage(AdAutoPlayVideoDto)

AdFeedbackPanelDto = _reflection.GeneratedProtocolMessageType('AdFeedbackPanelDto', (_message.Message,), {
  'DESCRIPTOR' : _ADFEEDBACKPANELDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdFeedbackPanelDto)
  })
_sym_db.RegisterMessage(AdFeedbackPanelDto)

AdFeedbackPanelModuleDto = _reflection.GeneratedProtocolMessageType('AdFeedbackPanelModuleDto', (_message.Message,), {
  'DESCRIPTOR' : _ADFEEDBACKPANELMODULEDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdFeedbackPanelModuleDto)
  })
_sym_db.RegisterMessage(AdFeedbackPanelModuleDto)

AdSecondFeedbackPanelDto = _reflection.GeneratedProtocolMessageType('AdSecondFeedbackPanelDto', (_message.Message,), {
  'DESCRIPTOR' : _ADSECONDFEEDBACKPANELDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdSecondFeedbackPanelDto)
  })
_sym_db.RegisterMessage(AdSecondFeedbackPanelDto)

AdGoodDto = _reflection.GeneratedProtocolMessageType('AdGoodDto', (_message.Message,), {
  'DESCRIPTOR' : _ADGOODDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdGoodDto)
  })
_sym_db.RegisterMessage(AdGoodDto)

QualityInfo = _reflection.GeneratedProtocolMessageType('QualityInfo', (_message.Message,), {
  'DESCRIPTOR' : _QUALITYINFO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.QualityInfo)
  })
_sym_db.RegisterMessage(QualityInfo)

AdverDto = _reflection.GeneratedProtocolMessageType('AdverDto', (_message.Message,), {
  'DESCRIPTOR' : _ADVERDTO,
  '__module__' : 'bilibili.ad.v1.ad_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.ad.v1.AdverDto)
  })
_sym_db.RegisterMessage(AdverDto)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ADSCONTROLDTO._serialized_start=75
  _ADSCONTROLDTO._serialized_end=164
  _ADOGVEPDTO._serialized_start=166
  _ADOGVEPDTO._serialized_end=215
  _SOURCECONTENTDTO._serialized_start=218
  _SOURCECONTENTDTO._serialized_end=491
  _ADDTO._serialized_start=494
  _ADDTO._serialized_end=761
  _ADCONTENTEXTRADTO._serialized_start=764
  _ADCONTENTEXTRADTO._serialized_end=1614
  _CREATIVEDTO._serialized_start=1617
  _CREATIVEDTO._serialized_end=1876
  _APPPACKAGEDTO._serialized_start=1879
  _APPPACKAGEDTO._serialized_end=2142
  _ADCARDDTO._serialized_start=2145
  _ADCARDDTO._serialized_end=3313
  _ADSHAREINFODTO._serialized_start=3315
  _ADSHAREINFODTO._serialized_end=3383
  _ADCOVERDTO._serialized_start=3385
  _ADCOVERDTO._serialized_end=3506
  _ADBUTTONDTO._serialized_start=3509
  _ADBUTTONDTO._serialized_end=3660
  _ADBUSINESSMARKDTO._serialized_start=3663
  _ADBUSINESSMARKDTO._serialized_end=3929
  _ADAUTOPLAYVIDEODTO._serialized_start=3932
  _ADAUTOPLAYVIDEODTO._serialized_end=4203
  _ADFEEDBACKPANELDTO._serialized_start=4205
  _ADFEEDBACKPANELDTO._serialized_end=4323
  _ADFEEDBACKPANELMODULEDTO._serialized_start=4326
  _ADFEEDBACKPANELMODULEDTO._serialized_end=4507
  _ADSECONDFEEDBACKPANELDTO._serialized_start=4509
  _ADSECONDFEEDBACKPANELDTO._serialized_end=4568
  _ADGOODDTO._serialized_start=4570
  _ADGOODDTO._serialized_end=4648
  _QUALITYINFO._serialized_start=4650
  _QUALITYINFO._serialized_end=4748
  _ADVERDTO._serialized_start=4751
  _ADVERDTO._serialized_end=4883
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AddContractReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COMMON_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    UP_MID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    @property
    def common(self) -> global___CommonReq:
        """"""
        pass
    mid: builtins.int
    """"""

    up_mid: builtins.int
    """"""

    aid: builtins.int
    """"""

    def __init__(self,
        *,
        common: typing.Optional[global___CommonReq] = ...,
        mid: builtins.int = ...,
        up_mid: builtins.int = ...,
        aid: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["common",b"common"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","common",b"common","mid",b"mid","up_mid",b"up_mid"]) -> None: ...
global___AddContractReq = AddContractReq

class CommonReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PLATFORM_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    platform: typing.Text
    """"""

    build: builtins.int
    """"""

    buvid: typing.Text
    """"""

    mobi_app: typing.Text
    """"""

    device: typing.Text
    """"""

    ip: typing.Text
    """"""

    spmid: typing.Text
    """"""

    def __init__(self,
        *,
        platform: typing.Text = ...,
        build: builtins.int = ...,
        buvid: typing.Text = ...,
        mobi_app: typing.Text = ...,
        device: typing.Text = ...,
        ip: typing.Text = ...,
        spmid: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build",b"build","buvid",b"buvid","device",b"device","ip",b"ip","mobi_app",b"mobi_app","platform",b"platform","spmid",b"spmid"]) -> None: ...
global___CommonReq = CommonReq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/note/sync.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*bilibili/broadcast/message/note/sync.proto\x12\x1f\x62ilibili.broadcast.message.note\"%\n\x04Sync\x12\x0f\n\x07note_id\x18\x01 \x01(\x03\x12\x0c\n\x04hash\x18\x02 \x01(\tb\x06proto3')



_SYNC = DESCRIPTOR.message_types_by_name['Sync']
Sync = _reflection.GeneratedProtocolMessageType('Sync', (_message.Message,), {
  'DESCRIPTOR' : _SYNC,
  '__module__' : 'bilibili.broadcast.message.note.sync_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.note.Sync)
  })
_sym_db.RegisterMessage(Sync)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SYNC._serialized_start=79
  _SYNC._serialized_end=116
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/pgc/service/premiere/v1/premiere.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/pgc/service/premiere/v1/premiere.proto\x12 bilibili.pgc.service.premiere.v1\"\"\n\x11PremiereStatusReq\x12\r\n\x05\x65p_id\x18\x01 \x01(\x03\"\x92\x01\n\x13PremiereStatusReply\x12\x10\n\x08progress\x18\x01 \x01(\x03\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\x12\n\ndelay_time\x18\x03 \x01(\x03\x12\x14\n\x0conline_count\x18\x04 \x01(\x03\x12\x0e\n\x06status\x18\x05 \x01(\x05\x12\x1b\n\x13\x61\x66ter_premiere_type\x18\x06 \x01(\x05\x32\x80\x01\n\x08Premiere\x12t\n\x06Status\x12\x33.bilibili.pgc.service.premiere.v1.PremiereStatusReq\x1a\x35.bilibili.pgc.service.premiere.v1.PremiereStatusReplyb\x06proto3')



_PREMIERESTATUSREQ = DESCRIPTOR.message_types_by_name['PremiereStatusReq']
_PREMIERESTATUSREPLY = DESCRIPTOR.message_types_by_name['PremiereStatusReply']
PremiereStatusReq = _reflection.GeneratedProtocolMessageType('PremiereStatusReq', (_message.Message,), {
  'DESCRIPTOR' : _PREMIERESTATUSREQ,
  '__module__' : 'bilibili.pgc.service.premiere.v1.premiere_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.service.premiere.v1.PremiereStatusReq)
  })
_sym_db.RegisterMessage(PremiereStatusReq)

PremiereStatusReply = _reflection.GeneratedProtocolMessageType('PremiereStatusReply', (_message.Message,), {
  'DESCRIPTOR' : _PREMIERESTATUSREPLY,
  '__module__' : 'bilibili.pgc.service.premiere.v1.premiere_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.service.premiere.v1.PremiereStatusReply)
  })
_sym_db.RegisterMessage(PremiereStatusReply)

_PREMIERE = DESCRIPTOR.services_by_name['Premiere']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PREMIERESTATUSREQ._serialized_start=85
  _PREMIERESTATUSREQ._serialized_end=119
  _PREMIERESTATUSREPLY._serialized_start=122
  _PREMIERESTATUSREPLY._serialized_end=268
  _PREMIERE._serialized_start=271
  _PREMIERE._serialized_end=399
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/interfaces/v1/history.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/app/interfaces/v1/history.proto\x12\x1a\x62ilibili.app.interfaces.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"\x99\x01\n\x0b\x43\x61rdArticle\x12\x0e\n\x06\x63overs\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x18\n\x10\x64isplayAttention\x18\x04 \x01(\x08\x12\r\n\x05\x62\x61\x64ge\x18\x05 \x01(\t\x12\x36\n\x08relation\x18\x06 \x01(\x0b\x32$.bilibili.app.interfaces.v1.Relation\"Q\n\nCardCheese\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x10\n\x08subtitle\x18\x04 \x01(\t\"\xa4\x01\n\x08\x43\x61rdLive\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0b\n\x03tag\x18\x04 \x01(\t\x12\x0e\n\x06ststus\x18\x05 \x01(\x05\x12\x19\n\x11\x64isplay_attention\x18\x06 \x01(\x08\x12\x36\n\x08relation\x18\x07 \x01(\x0b\x32$.bilibili.app.interfaces.v1.Relation\"N\n\x07\x43\x61rdOGV\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x10\n\x08subtitle\x18\x04 \x01(\t\"\xbe\x02\n\x07\x43\x61rdUGC\x12\r\n\x05\x63over\x18\x01 \x01(\t\x12\x10\n\x08progress\x18\x02 \x01(\x03\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0b\n\x03mid\x18\x05 \x01(\x03\x12\x19\n\x11\x64isplay_attention\x18\x06 \x01(\x08\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x0c\n\x04page\x18\x08 \x01(\x05\x12\x10\n\x08subtitle\x18\t \x01(\t\x12\x36\n\x08relation\x18\n \x01(\x0b\x32$.bilibili.app.interfaces.v1.Relation\x12\x0c\n\x04\x62vid\x18\x0b \x01(\t\x12\x0e\n\x06videos\x18\x0c \x01(\x03\x12\x12\n\nshort_link\x18\r \x01(\t\x12\x16\n\x0eshare_subtitle\x18\x0e \x01(\t\x12\x0c\n\x04view\x18\x0f \x01(\x03\x12\r\n\x05state\x18\x10 \x01(\x03\"\x1c\n\x08\x43learReq\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\"$\n\x06\x43ursor\x12\x0b\n\x03max\x18\x01 \x01(\x03\x12\r\n\x05maxTp\x18\x02 \x01(\x05\"\xf1\x03\n\nCursorItem\x12\x37\n\x08\x63\x61rd_ugc\x18\x01 \x01(\x0b\x32#.bilibili.app.interfaces.v1.CardUGCH\x00\x12\x37\n\x08\x63\x61rd_ogv\x18\x02 \x01(\x0b\x32#.bilibili.app.interfaces.v1.CardOGVH\x00\x12?\n\x0c\x63\x61rd_article\x18\x03 \x01(\x0b\x32\'.bilibili.app.interfaces.v1.CardArticleH\x00\x12\x39\n\tcard_live\x18\x04 \x01(\x0b\x32$.bilibili.app.interfaces.v1.CardLiveH\x00\x12=\n\x0b\x63\x61rd_cheese\x18\x05 \x01(\x0b\x32&.bilibili.app.interfaces.v1.CardCheeseH\x00\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x0e\n\x06viewAt\x18\x08 \x01(\x03\x12\x0b\n\x03kid\x18\t \x01(\x03\x12\x0b\n\x03oid\x18\n \x01(\x03\x12\x10\n\x08\x62usiness\x18\x0b \x01(\t\x12\n\n\x02tp\x18\x0c \x01(\x05\x12\x32\n\x02\x64t\x18\r \x01(\x0b\x32&.bilibili.app.interfaces.v1.DeviceType\x12\x11\n\thas_share\x18\x0e \x01(\x08\x42\x0b\n\tcard_item\"\xbd\x01\n\x0b\x43ursorReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.interfaces.v1.CursorItem\x12\x32\n\x03tab\x18\x02 \x03(\x0b\x32%.bilibili.app.interfaces.v1.CursorTab\x12\x32\n\x06\x63ursor\x18\x03 \x01(\x0b\x32\".bilibili.app.interfaces.v1.Cursor\x12\x0f\n\x07hasMore\x18\x04 \x01(\x08\"\xdf\x01\n\tCursorReq\x12\x32\n\x06\x63ursor\x18\x01 \x01(\x0b\x32\".bilibili.app.interfaces.v1.Cursor\x12\x10\n\x08\x62usiness\x18\x02 \x01(\t\x12G\n\x0eplayer_preload\x18\x03 \x01(\x0b\x32/.bilibili.app.interfaces.v1.PlayerPreloadParams\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"J\n\tCursorTab\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06router\x18\x03 \x01(\t\x12\r\n\x05\x66ocus\x18\x04 \x01(\x08\"\x9f\x01\n\rCursorV2Reply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.interfaces.v1.CursorItem\x12\x32\n\x06\x63ursor\x18\x02 \x01(\x0b\x32\".bilibili.app.interfaces.v1.Cursor\x12\x0f\n\x07hasMore\x18\x03 \x01(\x08\x12\x12\n\nempty_link\x18\x04 \x01(\t\"\xf3\x01\n\x0b\x43ursorV2Req\x12\x32\n\x06\x63ursor\x18\x01 \x01(\x0b\x32\".bilibili.app.interfaces.v1.Cursor\x12\x10\n\x08\x62usiness\x18\x02 \x01(\t\x12G\n\x0eplayer_preload\x18\x03 \x01(\x0b\x32/.bilibili.app.interfaces.v1.PlayerPreloadParams\x12\x43\n\x0bplayer_args\x18\x04 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x10\n\x08is_local\x18\x05 \x01(\x08\"B\n\tDeleteReq\x12\x35\n\x08his_info\x18\x01 \x01(\x0b\x32#.bilibili.app.interfaces.v1.HisInfo\"H\n\nDeviceType\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.bilibili.app.interfaces.v1.DT\x12\x0c\n\x04icon\x18\x02 \x01(\t\"(\n\x07HisInfo\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x0b\n\x03kid\x18\x02 \x01(\x03\"E\n\x0fHistoryTabReply\x12\x32\n\x03tab\x18\x01 \x03(\x0b\x32%.bilibili.app.interfaces.v1.CursorTab\"m\n\rHistoryTabReq\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12\x39\n\x06source\x18\x02 \x01(\x0e\x32).bilibili.app.interfaces.v1.HistorySource\x12\x0f\n\x07keyword\x18\x03 \x01(\t\"w\n\x12LatestHistoryReply\x12\x35\n\x05items\x18\x01 \x01(\x0b\x32&.bilibili.app.interfaces.v1.CursorItem\x12\r\n\x05scene\x18\x02 \x01(\t\x12\r\n\x05rtime\x18\x03 \x01(\x03\x12\x0c\n\x04\x66lag\x18\x04 \x01(\t\"m\n\x10LatestHistoryReq\x12\x10\n\x08\x62usiness\x18\x01 \x01(\t\x12G\n\x0eplayer_preload\x18\x02 \x01(\x0b\x32/.bilibili.app.interfaces.v1.PlayerPreloadParams\"\t\n\x07NoReply\"!\n\x04Page\x12\n\n\x02pn\x18\x01 \x01(\x03\x12\r\n\x05total\x18\x02 \x01(\x03\"a\n\x13PlayerPreloadParams\x12\n\n\x02qn\x18\x01 \x01(\x03\x12\r\n\x05\x66nver\x18\x02 \x01(\x03\x12\r\n\x05\x66nval\x18\x03 \x01(\x03\x12\x11\n\tforceHost\x18\x04 \x01(\x03\x12\r\n\x05\x66ourk\x18\x05 \x01(\x03\"B\n\x08Relation\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\"\x85\x01\n\x0bSearchReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.interfaces.v1.CursorItem\x12\x0f\n\x07hasMore\x18\x02 \x01(\x08\x12.\n\x04page\x18\x03 \x01(\x0b\x32 .bilibili.app.interfaces.v1.Page\":\n\tSearchReq\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\n\n\x02pn\x18\x02 \x01(\x03\x12\x10\n\x08\x62usiness\x18\x03 \x01(\t*S\n\x02\x44T\x12\x0b\n\x07Unknown\x10\x00\x12\t\n\x05Phone\x10\x01\x12\x07\n\x03Pad\x10\x02\x12\x06\n\x02PC\x10\x03\x12\x06\n\x02TV\x10\x04\x12\x07\n\x03\x43\x61r\x10\x05\x12\x07\n\x03Iot\x10\x06\x12\n\n\x06\x41ndPad\x10\x07*6\n\rHistorySource\x12\x11\n\rhistory_VALUE\x10\x00\x12\x12\n\x0eshopping_VALUE\x10\x01\x32\x9c\x05\n\x07History\x12\x64\n\nHistoryTab\x12).bilibili.app.interfaces.v1.HistoryTabReq\x1a+.bilibili.app.interfaces.v1.HistoryTabReply\x12X\n\x06\x43ursor\x12%.bilibili.app.interfaces.v1.CursorReq\x1a\'.bilibili.app.interfaces.v1.CursorReply\x12^\n\x08\x43ursorV2\x12\'.bilibili.app.interfaces.v1.CursorV2Req\x1a).bilibili.app.interfaces.v1.CursorV2Reply\x12T\n\x06\x44\x65lete\x12%.bilibili.app.interfaces.v1.DeleteReq\x1a#.bilibili.app.interfaces.v1.NoReply\x12X\n\x06Search\x12%.bilibili.app.interfaces.v1.SearchReq\x1a\'.bilibili.app.interfaces.v1.SearchReply\x12R\n\x05\x43lear\x12$.bilibili.app.interfaces.v1.ClearReq\x1a#.bilibili.app.interfaces.v1.NoReply\x12m\n\rLatestHistory\x12,.bilibili.app.interfaces.v1.LatestHistoryReq\x1a..bilibili.app.interfaces.v1.LatestHistoryReplyb\x06proto3')

_DT = DESCRIPTOR.enum_types_by_name['DT']
DT = enum_type_wrapper.EnumTypeWrapper(_DT)
_HISTORYSOURCE = DESCRIPTOR.enum_types_by_name['HistorySource']
HistorySource = enum_type_wrapper.EnumTypeWrapper(_HISTORYSOURCE)
Unknown = 0
Phone = 1
Pad = 2
PC = 3
TV = 4
Car = 5
Iot = 6
AndPad = 7
history_VALUE = 0
shopping_VALUE = 1


_CARDARTICLE = DESCRIPTOR.message_types_by_name['CardArticle']
_CARDCHEESE = DESCRIPTOR.message_types_by_name['CardCheese']
_CARDLIVE = DESCRIPTOR.message_types_by_name['CardLive']
_CARDOGV = DESCRIPTOR.message_types_by_name['CardOGV']
_CARDUGC = DESCRIPTOR.message_types_by_name['CardUGC']
_CLEARREQ = DESCRIPTOR.message_types_by_name['ClearReq']
_CURSOR = DESCRIPTOR.message_types_by_name['Cursor']
_CURSORITEM = DESCRIPTOR.message_types_by_name['CursorItem']
_CURSORREPLY = DESCRIPTOR.message_types_by_name['CursorReply']
_CURSORREQ = DESCRIPTOR.message_types_by_name['CursorReq']
_CURSORTAB = DESCRIPTOR.message_types_by_name['CursorTab']
_CURSORV2REPLY = DESCRIPTOR.message_types_by_name['CursorV2Reply']
_CURSORV2REQ = DESCRIPTOR.message_types_by_name['CursorV2Req']
_DELETEREQ = DESCRIPTOR.message_types_by_name['DeleteReq']
_DEVICETYPE = DESCRIPTOR.message_types_by_name['DeviceType']
_HISINFO = DESCRIPTOR.message_types_by_name['HisInfo']
_HISTORYTABREPLY = DESCRIPTOR.message_types_by_name['HistoryTabReply']
_HISTORYTABREQ = DESCRIPTOR.message_types_by_name['HistoryTabReq']
_LATESTHISTORYREPLY = DESCRIPTOR.message_types_by_name['LatestHistoryReply']
_LATESTHISTORYREQ = DESCRIPTOR.message_types_by_name['LatestHistoryReq']
_NOREPLY = DESCRIPTOR.message_types_by_name['NoReply']
_PAGE = DESCRIPTOR.message_types_by_name['Page']
_PLAYERPRELOADPARAMS = DESCRIPTOR.message_types_by_name['PlayerPreloadParams']
_RELATION = DESCRIPTOR.message_types_by_name['Relation']
_SEARCHREPLY = DESCRIPTOR.message_types_by_name['SearchReply']
_SEARCHREQ = DESCRIPTOR.message_types_by_name['SearchReq']
CardArticle = _reflection.GeneratedProtocolMessageType('CardArticle', (_message.Message,), {
  'DESCRIPTOR' : _CARDARTICLE,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CardArticle)
  })
_sym_db.RegisterMessage(CardArticle)

CardCheese = _reflection.GeneratedProtocolMessageType('CardCheese', (_message.Message,), {
  'DESCRIPTOR' : _CARDCHEESE,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CardCheese)
  })
_sym_db.RegisterMessage(CardCheese)

CardLive = _reflection.GeneratedProtocolMessageType('CardLive', (_message.Message,), {
  'DESCRIPTOR' : _CARDLIVE,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CardLive)
  })
_sym_db.RegisterMessage(CardLive)

CardOGV = _reflection.GeneratedProtocolMessageType('CardOGV', (_message.Message,), {
  'DESCRIPTOR' : _CARDOGV,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CardOGV)
  })
_sym_db.RegisterMessage(CardOGV)

CardUGC = _reflection.GeneratedProtocolMessageType('CardUGC', (_message.Message,), {
  'DESCRIPTOR' : _CARDUGC,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CardUGC)
  })
_sym_db.RegisterMessage(CardUGC)

ClearReq = _reflection.GeneratedProtocolMessageType('ClearReq', (_message.Message,), {
  'DESCRIPTOR' : _CLEARREQ,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.ClearReq)
  })
_sym_db.RegisterMessage(ClearReq)

Cursor = _reflection.GeneratedProtocolMessageType('Cursor', (_message.Message,), {
  'DESCRIPTOR' : _CURSOR,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.Cursor)
  })
_sym_db.RegisterMessage(Cursor)

CursorItem = _reflection.GeneratedProtocolMessageType('CursorItem', (_message.Message,), {
  'DESCRIPTOR' : _CURSORITEM,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CursorItem)
  })
_sym_db.RegisterMessage(CursorItem)

CursorReply = _reflection.GeneratedProtocolMessageType('CursorReply', (_message.Message,), {
  'DESCRIPTOR' : _CURSORREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CursorReply)
  })
_sym_db.RegisterMessage(CursorReply)

CursorReq = _reflection.GeneratedProtocolMessageType('CursorReq', (_message.Message,), {
  'DESCRIPTOR' : _CURSORREQ,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CursorReq)
  })
_sym_db.RegisterMessage(CursorReq)

CursorTab = _reflection.GeneratedProtocolMessageType('CursorTab', (_message.Message,), {
  'DESCRIPTOR' : _CURSORTAB,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CursorTab)
  })
_sym_db.RegisterMessage(CursorTab)

CursorV2Reply = _reflection.GeneratedProtocolMessageType('CursorV2Reply', (_message.Message,), {
  'DESCRIPTOR' : _CURSORV2REPLY,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CursorV2Reply)
  })
_sym_db.RegisterMessage(CursorV2Reply)

CursorV2Req = _reflection.GeneratedProtocolMessageType('CursorV2Req', (_message.Message,), {
  'DESCRIPTOR' : _CURSORV2REQ,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.CursorV2Req)
  })
_sym_db.RegisterMessage(CursorV2Req)

DeleteReq = _reflection.GeneratedProtocolMessageType('DeleteReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREQ,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.DeleteReq)
  })
_sym_db.RegisterMessage(DeleteReq)

DeviceType = _reflection.GeneratedProtocolMessageType('DeviceType', (_message.Message,), {
  'DESCRIPTOR' : _DEVICETYPE,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.DeviceType)
  })
_sym_db.RegisterMessage(DeviceType)

HisInfo = _reflection.GeneratedProtocolMessageType('HisInfo', (_message.Message,), {
  'DESCRIPTOR' : _HISINFO,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.HisInfo)
  })
_sym_db.RegisterMessage(HisInfo)

HistoryTabReply = _reflection.GeneratedProtocolMessageType('HistoryTabReply', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYTABREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.HistoryTabReply)
  })
_sym_db.RegisterMessage(HistoryTabReply)

HistoryTabReq = _reflection.GeneratedProtocolMessageType('HistoryTabReq', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYTABREQ,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.HistoryTabReq)
  })
_sym_db.RegisterMessage(HistoryTabReq)

LatestHistoryReply = _reflection.GeneratedProtocolMessageType('LatestHistoryReply', (_message.Message,), {
  'DESCRIPTOR' : _LATESTHISTORYREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.LatestHistoryReply)
  })
_sym_db.RegisterMessage(LatestHistoryReply)

LatestHistoryReq = _reflection.GeneratedProtocolMessageType('LatestHistoryReq', (_message.Message,), {
  'DESCRIPTOR' : _LATESTHISTORYREQ,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.LatestHistoryReq)
  })
_sym_db.RegisterMessage(LatestHistoryReq)

NoReply = _reflection.GeneratedProtocolMessageType('NoReply', (_message.Message,), {
  'DESCRIPTOR' : _NOREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.NoReply)
  })
_sym_db.RegisterMessage(NoReply)

Page = _reflection.GeneratedProtocolMessageType('Page', (_message.Message,), {
  'DESCRIPTOR' : _PAGE,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.Page)
  })
_sym_db.RegisterMessage(Page)

PlayerPreloadParams = _reflection.GeneratedProtocolMessageType('PlayerPreloadParams', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERPRELOADPARAMS,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.PlayerPreloadParams)
  })
_sym_db.RegisterMessage(PlayerPreloadParams)

Relation = _reflection.GeneratedProtocolMessageType('Relation', (_message.Message,), {
  'DESCRIPTOR' : _RELATION,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.Relation)
  })
_sym_db.RegisterMessage(Relation)

SearchReply = _reflection.GeneratedProtocolMessageType('SearchReply', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREPLY,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchReply)
  })
_sym_db.RegisterMessage(SearchReply)

SearchReq = _reflection.GeneratedProtocolMessageType('SearchReq', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREQ,
  '__module__' : 'bilibili.app.interfaces.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SearchReq)
  })
_sym_db.RegisterMessage(SearchReq)

_HISTORY = DESCRIPTOR.services_by_name['History']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DT._serialized_start=3406
  _DT._serialized_end=3489
  _HISTORYSOURCE._serialized_start=3491
  _HISTORYSOURCE._serialized_end=3545
  _CARDARTICLE._serialized_start=123
  _CARDARTICLE._serialized_end=276
  _CARDCHEESE._serialized_start=278
  _CARDCHEESE._serialized_end=359
  _CARDLIVE._serialized_start=362
  _CARDLIVE._serialized_end=526
  _CARDOGV._serialized_start=528
  _CARDOGV._serialized_end=606
  _CARDUGC._serialized_start=609
  _CARDUGC._serialized_end=927
  _CLEARREQ._serialized_start=929
  _CLEARREQ._serialized_end=957
  _CURSOR._serialized_start=959
  _CURSOR._serialized_end=995
  _CURSORITEM._serialized_start=998
  _CURSORITEM._serialized_end=1495
  _CURSORREPLY._serialized_start=1498
  _CURSORREPLY._serialized_end=1687
  _CURSORREQ._serialized_start=1690
  _CURSORREQ._serialized_end=1913
  _CURSORTAB._serialized_start=1915
  _CURSORTAB._serialized_end=1989
  _CURSORV2REPLY._serialized_start=1992
  _CURSORV2REPLY._serialized_end=2151
  _CURSORV2REQ._serialized_start=2154
  _CURSORV2REQ._serialized_end=2397
  _DELETEREQ._serialized_start=2399
  _DELETEREQ._serialized_end=2465
  _DEVICETYPE._serialized_start=2467
  _DEVICETYPE._serialized_end=2539
  _HISINFO._serialized_start=2541
  _HISINFO._serialized_end=2581
  _HISTORYTABREPLY._serialized_start=2583
  _HISTORYTABREPLY._serialized_end=2652
  _HISTORYTABREQ._serialized_start=2654
  _HISTORYTABREQ._serialized_end=2763
  _LATESTHISTORYREPLY._serialized_start=2765
  _LATESTHISTORYREPLY._serialized_end=2884
  _LATESTHISTORYREQ._serialized_start=2886
  _LATESTHISTORYREQ._serialized_end=2995
  _NOREPLY._serialized_start=2997
  _NOREPLY._serialized_end=3006
  _PAGE._serialized_start=3008
  _PAGE._serialized_end=3041
  _PLAYERPRELOADPARAMS._serialized_start=3043
  _PLAYERPRELOADPARAMS._serialized_end=3140
  _RELATION._serialized_start=3142
  _RELATION._serialized_end=3208
  _SEARCHREPLY._serialized_start=3211
  _SEARCHREPLY._serialized_end=3344
  _SEARCHREQ._serialized_start=3346
  _SEARCHREQ._serialized_end=3404
  _HISTORY._serialized_start=3548
  _HISTORY._serialized_end=4216
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/api/probe/v1/probe.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!bilibili/api/probe/v1/probe.proto\x12\x15\x62ilibili.api.probe.v1\"\x17\n\x07\x43odeReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\"\x0b\n\tCodeReply\"&\n\x08ProbeReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05\x62uvid\x18\x02 \x01(\t\"0\n\nProbeReply\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\"/\n\x0eProbeStreamReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x10\n\x08sequence\x18\x02 \x01(\x03\"H\n\x10ProbeStreamReply\x12\x10\n\x08sequence\x18\x01 \x01(\x03\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\"\x1c\n\x0bProbeSubReq\x12\r\n\x05\x62uvid\x18\x01 \x01(\x03\"#\n\rProbeSubReply\x12\x12\n\nmessage_id\x18\x01 \x01(\x03\x32\xd7\x02\n\x05Probe\x12L\n\x08TestCode\x12\x1e.bilibili.api.probe.v1.CodeReq\x1a .bilibili.api.probe.v1.CodeReply\x12M\n\x07TestReq\x12\x1f.bilibili.api.probe.v1.ProbeReq\x1a!.bilibili.api.probe.v1.ProbeReply\x12\\\n\nTestStream\x12%.bilibili.api.probe.v1.ProbeStreamReq\x1a\'.bilibili.api.probe.v1.ProbeStreamReply\x12S\n\x07TestSub\x12\".bilibili.api.probe.v1.ProbeSubReq\x1a$.bilibili.api.probe.v1.ProbeSubReplyb\x06proto3')



_CODEREQ = DESCRIPTOR.message_types_by_name['CodeReq']
_CODEREPLY = DESCRIPTOR.message_types_by_name['CodeReply']
_PROBEREQ = DESCRIPTOR.message_types_by_name['ProbeReq']
_PROBEREPLY = DESCRIPTOR.message_types_by_name['ProbeReply']
_PROBESTREAMREQ = DESCRIPTOR.message_types_by_name['ProbeStreamReq']
_PROBESTREAMREPLY = DESCRIPTOR.message_types_by_name['ProbeStreamReply']
_PROBESUBREQ = DESCRIPTOR.message_types_by_name['ProbeSubReq']
_PROBESUBREPLY = DESCRIPTOR.message_types_by_name['ProbeSubReply']
CodeReq = _reflection.GeneratedProtocolMessageType('CodeReq', (_message.Message,), {
  'DESCRIPTOR' : _CODEREQ,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.CodeReq)
  })
_sym_db.RegisterMessage(CodeReq)

CodeReply = _reflection.GeneratedProtocolMessageType('CodeReply', (_message.Message,), {
  'DESCRIPTOR' : _CODEREPLY,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.CodeReply)
  })
_sym_db.RegisterMessage(CodeReply)

ProbeReq = _reflection.GeneratedProtocolMessageType('ProbeReq', (_message.Message,), {
  'DESCRIPTOR' : _PROBEREQ,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeReq)
  })
_sym_db.RegisterMessage(ProbeReq)

ProbeReply = _reflection.GeneratedProtocolMessageType('ProbeReply', (_message.Message,), {
  'DESCRIPTOR' : _PROBEREPLY,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeReply)
  })
_sym_db.RegisterMessage(ProbeReply)

ProbeStreamReq = _reflection.GeneratedProtocolMessageType('ProbeStreamReq', (_message.Message,), {
  'DESCRIPTOR' : _PROBESTREAMREQ,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeStreamReq)
  })
_sym_db.RegisterMessage(ProbeStreamReq)

ProbeStreamReply = _reflection.GeneratedProtocolMessageType('ProbeStreamReply', (_message.Message,), {
  'DESCRIPTOR' : _PROBESTREAMREPLY,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeStreamReply)
  })
_sym_db.RegisterMessage(ProbeStreamReply)

ProbeSubReq = _reflection.GeneratedProtocolMessageType('ProbeSubReq', (_message.Message,), {
  'DESCRIPTOR' : _PROBESUBREQ,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeSubReq)
  })
_sym_db.RegisterMessage(ProbeSubReq)

ProbeSubReply = _reflection.GeneratedProtocolMessageType('ProbeSubReply', (_message.Message,), {
  'DESCRIPTOR' : _PROBESUBREPLY,
  '__module__' : 'bilibili.api.probe.v1.probe_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.api.probe.v1.ProbeSubReply)
  })
_sym_db.RegisterMessage(ProbeSubReply)

_PROBE = DESCRIPTOR.services_by_name['Probe']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CODEREQ._serialized_start=60
  _CODEREQ._serialized_end=83
  _CODEREPLY._serialized_start=85
  _CODEREPLY._serialized_end=96
  _PROBEREQ._serialized_start=98
  _PROBEREQ._serialized_end=136
  _PROBEREPLY._serialized_start=138
  _PROBEREPLY._serialized_end=186
  _PROBESTREAMREQ._serialized_start=188
  _PROBESTREAMREQ._serialized_end=235
  _PROBESTREAMREPLY._serialized_start=237
  _PROBESTREAMREPLY._serialized_end=309
  _PROBESUBREQ._serialized_start=311
  _PROBESUBREQ._serialized_end=339
  _PROBESUBREPLY._serialized_start=341
  _PROBESUBREPLY._serialized_end=376
  _PROBE._serialized_start=379
  _PROBE._serialized_end=722
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BanUser(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UID_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """用户mid"""

    limit: builtins.int
    """封禁业务"""

    time: builtins.int
    """封禁时间"""

    mode: builtins.int
    """模式
    1:add 2:remove
    """

    def __init__(self,
        *,
        uid: builtins.int = ...,
        limit: builtins.int = ...,
        time: builtins.int = ...,
        mode: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["limit",b"limit","mode",b"mode","time",b"time","uid",b"uid"]) -> None: ...
global___BanUser = BanUser

class ReqOpBlacklist(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BAN_USERS_FIELD_NUMBER: builtins.int
    @property
    def ban_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BanUser]:
        """需要封禁/解封的用户信息"""
        pass
    def __init__(self,
        *,
        ban_users: typing.Optional[typing.Iterable[global___BanUser]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ban_users",b"ban_users"]) -> None: ...
global___ReqOpBlacklist = ReqOpBlacklist

class RspOpBlacklist(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FAILED_USERS_FIELD_NUMBER: builtins.int
    @property
    def failed_users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
        pass
    def __init__(self,
        *,
        failed_users: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failed_users",b"failed_users"]) -> None: ...
global___RspOpBlacklist = RspOpBlacklist



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RuleRequest(google.protobuf.message.Message):
    """获取免流规则信息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___RuleRequest = RuleRequest

class RulesReply(google.protobuf.message.Message):
    """获取免流规则信息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class RulesInfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___RulesInfo: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___RulesInfo] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    RULESINFO_FIELD_NUMBER: builtins.int
    @property
    def rulesInfo(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___RulesInfo]:
        """各ISP的免流规则信息组
        ISP如: cu ct cm
        """
        pass
    def __init__(self,
        *,
        rulesInfo: typing.Optional[typing.Mapping[typing.Text, global___RulesInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rulesInfo",b"rulesInfo"]) -> None: ...
global___RulesReply = RulesReply

class RuleInfo(google.protobuf.message.Message):
    """免流规则信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TF_FIELD_NUMBER: builtins.int
    M_FIELD_NUMBER: builtins.int
    A_FIELD_NUMBER: builtins.int
    P_FIELD_NUMBER: builtins.int
    tf: builtins.bool
    """是否支持免流"""

    m: typing.Text
    """操作模式
    break:无 replace:替换 proxy:代理
    """

    a: typing.Text
    """操作参数"""

    p: typing.Text
    """匹配目标正则"""

    def __init__(self,
        *,
        tf: builtins.bool = ...,
        m: typing.Text = ...,
        a: typing.Text = ...,
        p: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["a",b"a","m",b"m","p",b"p","tf",b"tf"]) -> None: ...
global___RuleInfo = RuleInfo

class RulesInfo(google.protobuf.message.Message):
    """免流规则信息组"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RULESINFO_FIELD_NUMBER: builtins.int
    @property
    def rulesInfo(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuleInfo]:
        """免流规则信息"""
        pass
    def __init__(self,
        *,
        rulesInfo: typing.Optional[typing.Iterable[global___RuleInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rulesInfo",b"rulesInfo"]) -> None: ...
global___RulesInfo = RulesInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/live/general/interfaces/v1/interfaces.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4bilibili/live/general/interfaces/v1/interfaces.proto\x12#bilibili.live.general.interfaces.v1\"d\n\x10GetOnlineRankReq\x12\x0c\n\x04ruid\x18\x01 \x01(\x03\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0c\n\x04page\x18\x03 \x01(\x03\x12\x11\n\tpage_size\x18\x04 \x01(\x03\x12\x10\n\x08platform\x18\x05 \x01(\t\"\xaa\x02\n\x11GetOnlineRankResp\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.bilibili.live.general.interfaces.v1.GetOnlineRankResp.OnlineRankItem\x12\x12\n\nonline_num\x18\x02 \x01(\x03\x1a\xab\x01\n\x0eOnlineRankItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x16\n\x0e\x63ontinue_watch\x18\x04 \x01(\x03\x12\x42\n\nmedal_info\x18\x05 \x01(\x0b\x32..bilibili.live.general.interfaces.v1.MedalInfo\x12\x13\n\x0bguard_level\x18\x06 \x01(\x03\"\xb8\x01\n\tMedalInfo\x12\x13\n\x0bguard_level\x18\x01 \x01(\x03\x12\x19\n\x11medal_color_start\x18\x02 \x01(\x03\x12\x17\n\x0fmedal_color_end\x18\x03 \x01(\x03\x12\x1a\n\x12medal_color_border\x18\x04 \x01(\x03\x12\x12\n\nmedal_name\x18\x05 \x01(\t\x12\r\n\x05level\x18\x06 \x01(\x03\x12\x11\n\ttarget_id\x18\x07 \x01(\x03\x12\x10\n\x08is_light\x18\x08 \x01(\x03\x62\x06proto3')



_GETONLINERANKREQ = DESCRIPTOR.message_types_by_name['GetOnlineRankReq']
_GETONLINERANKRESP = DESCRIPTOR.message_types_by_name['GetOnlineRankResp']
_GETONLINERANKRESP_ONLINERANKITEM = _GETONLINERANKRESP.nested_types_by_name['OnlineRankItem']
_MEDALINFO = DESCRIPTOR.message_types_by_name['MedalInfo']
GetOnlineRankReq = _reflection.GeneratedProtocolMessageType('GetOnlineRankReq', (_message.Message,), {
  'DESCRIPTOR' : _GETONLINERANKREQ,
  '__module__' : 'bilibili.live.general.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.live.general.interfaces.v1.GetOnlineRankReq)
  })
_sym_db.RegisterMessage(GetOnlineRankReq)

GetOnlineRankResp = _reflection.GeneratedProtocolMessageType('GetOnlineRankResp', (_message.Message,), {

  'OnlineRankItem' : _reflection.GeneratedProtocolMessageType('OnlineRankItem', (_message.Message,), {
    'DESCRIPTOR' : _GETONLINERANKRESP_ONLINERANKITEM,
    '__module__' : 'bilibili.live.general.interfaces.v1.interfaces_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.live.general.interfaces.v1.GetOnlineRankResp.OnlineRankItem)
    })
  ,
  'DESCRIPTOR' : _GETONLINERANKRESP,
  '__module__' : 'bilibili.live.general.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.live.general.interfaces.v1.GetOnlineRankResp)
  })
_sym_db.RegisterMessage(GetOnlineRankResp)
_sym_db.RegisterMessage(GetOnlineRankResp.OnlineRankItem)

MedalInfo = _reflection.GeneratedProtocolMessageType('MedalInfo', (_message.Message,), {
  'DESCRIPTOR' : _MEDALINFO,
  '__module__' : 'bilibili.live.general.interfaces.v1.interfaces_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.live.general.interfaces.v1.MedalInfo)
  })
_sym_db.RegisterMessage(MedalInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETONLINERANKREQ._serialized_start=93
  _GETONLINERANKREQ._serialized_end=193
  _GETONLINERANKRESP._serialized_start=196
  _GETONLINERANKRESP._serialized_end=494
  _GETONLINERANKRESP_ONLINERANKITEM._serialized_start=323
  _GETONLINERANKRESP_ONLINERANKITEM._serialized_end=494
  _MEDALINFO._serialized_start=497
  _MEDALINFO._serialized_end=681
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/polymer/list/list.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/polymer/list/list.proto\x12\x15\x62ilibili.polymer.list\"#\n\x11\x43heckAccountReply\x12\x0e\n\x06is_new\x18\x01 \x01(\x08\"/\n\x0f\x43heckAccountReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x0f\n\x07periods\x18\x02 \x01(\t\":\n\x0f\x46\x61voriteTabItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"I\n\x10\x46\x61voriteTabReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.polymer.list.FavoriteTabItem\"\x10\n\x0e\x46\x61voriteTabReq2\xc7\x01\n\x04List\x12]\n\x0b\x46\x61voriteTab\x12%.bilibili.polymer.list.FavoriteTabReq\x1a\'.bilibili.polymer.list.FavoriteTabReply\x12`\n\x0c\x43heckAccount\x12&.bilibili.polymer.list.CheckAccountReq\x1a(.bilibili.polymer.list.CheckAccountReplyb\x06proto3')



_CHECKACCOUNTREPLY = DESCRIPTOR.message_types_by_name['CheckAccountReply']
_CHECKACCOUNTREQ = DESCRIPTOR.message_types_by_name['CheckAccountReq']
_FAVORITETABITEM = DESCRIPTOR.message_types_by_name['FavoriteTabItem']
_FAVORITETABREPLY = DESCRIPTOR.message_types_by_name['FavoriteTabReply']
_FAVORITETABREQ = DESCRIPTOR.message_types_by_name['FavoriteTabReq']
CheckAccountReply = _reflection.GeneratedProtocolMessageType('CheckAccountReply', (_message.Message,), {
  'DESCRIPTOR' : _CHECKACCOUNTREPLY,
  '__module__' : 'bilibili.polymer.list.list_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.polymer.list.CheckAccountReply)
  })
_sym_db.RegisterMessage(CheckAccountReply)

CheckAccountReq = _reflection.GeneratedProtocolMessageType('CheckAccountReq', (_message.Message,), {
  'DESCRIPTOR' : _CHECKACCOUNTREQ,
  '__module__' : 'bilibili.polymer.list.list_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.polymer.list.CheckAccountReq)
  })
_sym_db.RegisterMessage(CheckAccountReq)

FavoriteTabItem = _reflection.GeneratedProtocolMessageType('FavoriteTabItem', (_message.Message,), {
  'DESCRIPTOR' : _FAVORITETABITEM,
  '__module__' : 'bilibili.polymer.list.list_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.polymer.list.FavoriteTabItem)
  })
_sym_db.RegisterMessage(FavoriteTabItem)

FavoriteTabReply = _reflection.GeneratedProtocolMessageType('FavoriteTabReply', (_message.Message,), {
  'DESCRIPTOR' : _FAVORITETABREPLY,
  '__module__' : 'bilibili.polymer.list.list_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.polymer.list.FavoriteTabReply)
  })
_sym_db.RegisterMessage(FavoriteTabReply)

FavoriteTabReq = _reflection.GeneratedProtocolMessageType('FavoriteTabReq', (_message.Message,), {
  'DESCRIPTOR' : _FAVORITETABREQ,
  '__module__' : 'bilibili.polymer.list.list_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.polymer.list.FavoriteTabReq)
  })
_sym_db.RegisterMessage(FavoriteTabReq)

_LIST = DESCRIPTOR.services_by_name['List']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHECKACCOUNTREPLY._serialized_start=59
  _CHECKACCOUNTREPLY._serialized_end=94
  _CHECKACCOUNTREQ._serialized_start=96
  _CHECKACCOUNTREQ._serialized_end=143
  _FAVORITETABITEM._serialized_start=145
  _FAVORITETABITEM._serialized_end=203
  _FAVORITETABREPLY._serialized_start=205
  _FAVORITETABREPLY._serialized_end=278
  _FAVORITETABREQ._serialized_start=280
  _FAVORITETABREQ._serialized_end=296
  _LIST._serialized_start=299
  _LIST._serialized_end=498
# @@protoc_insertion_point(module_scope)
